/*
 * *********************************************************************************************************************
 *
 *          !!
 *        .F88X
 *        X8888Y
 *      .}888888N;
 *        i888888N;        .:!              .I$WI:
 *          R888888I      .'N88~            i8}+8Y&8"l8i$8>8W~'>W8}8]KW+8IIN"8&
 *          .R888888I    .;N8888~          .X8'  "8I.!,/8"  !%NY8`"8I8~~8>,88I
 *            +888888N;  .8888888Y                                  "&&8Y.}8,
 *            ./888888N;  .R888888Y        .'}~    .>}'.`+>  i}!    "i'  +/'  .'i~  !11,.:">,  .~]!  .i}i
 *              ~888888%:  .I888888l      .]88~`1/iY88Ii+1'.R$8$8]"888888888>  Y8$  W8E  X8E  W8888'188Il}Y88$*
 *              18888888    E8888881    .]W%8$`R8X'&8%++N8i,8N%N8+l8%`  .}8N:.R$RE%N88N%N$K$R  188,FE$8%~Y88I
 *            .E888888I  .i8888888'      .:$8I;88+`E8R:/8N,.>881.`$8E/1/]N8X.Y8N`"KF&&FK!'88*."88K./$88%RN888+~
 *            8888888I  .,N888888~        ~88i"8W,!N8*.I88.}888%F,i$88"F88"  888:E8X.>88!i88>`888*.}Fl1]*}1YKi'
 *          i888888N'      I888Y          ]88;/EX*IFKFK88X  K8R  .l8W  88Y  ~88}'88E&%8W.X8N``]88!.$8K  .:W8I
 *        .i888888N;        I8Y          .&8$  .X88!  i881.:%888>I88  ;88]  +88+.';;;;:.Y88X  18N.,88l  .+88/
 *      .:R888888I
 *      .&888888I                                          Copyright (c) 2016-2020.  博锐尚格科技股份有限公司
 *        ~8888'
 *        .!88~                                                                     All rights reserved.
 *
 * *********************************************************************************************************************
 */

import { SGraphScene, SGraphItem } from "@persagy-web/graph";
import { SPoint } from "@persagy-web/draw";
import { SMouseEvent, SUndoStack, } from "@persagy-web/base";
import { SRectSelectItem } from "@persagy-web/big";

/**
 * Graphy图形引擎编辑场景类
 *
 * @author  韩耀龙(han_yao_long@126.com)
 */
export class GraphEditScene extends SGraphScene {
    /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
    //属性
    /** undo/redo存储栈 */
    protected _undoStack = new SUndoStack();
    get undoStack(): SUndoStack {
        return this._undoStack
    }
    set undoStack(val: SUndoStack) {
        this._undoStack = val
    }
    /**编辑命令 */
    _editCmd: string = ""
    get editCmd(): string {
        return this._editCmd
    }
    set editCmd(val: string) {
        this._editCmd = val;
    }
    /**是否可编辑 */
    _isEditStatus: Boolean = true; // 是否可编辑
    set isEditStatus(bol: Boolean) {
        this._isEditStatus = bol;
    }
    get isEditStatus(): Boolean {
        return this._isEditStatus
    }
    /////////////////////////////////////////////////////////////////////////////////////////////////////////////////
    //函数
    constructor() {
        super()
        // // 选择绑定选额item事件
        this.selectContainer.connect("selectChange", this, this.selectChange);
    }

    /**
     * 选中item触发方法
     *
     * @param obj 变化后的对象
     */
    selectChange(obj: any) { }

    /**
     * 增加直线线段item
     * @param SMouseEvent  鼠标事件
     */
    addLine(event: SMouseEvent) {
    }

    /**
     * 增加折线线段item
     * @param SMouseEvent  鼠标事件
     */
    addPolyline(event: SMouseEvent) {
    }

    /**
     * 增加多边形item
     * @param SMouseEvent  鼠标事件
     */
    addPolygonItem(event: SMouseEvent) {
    }

    /**
     * 增加图片item
     * @param SMouseEvent  鼠标事件
     */
    addImgItem(event: SMouseEvent) {
    }

    /**
     * 增加文本item
     * @param SMouseEvent  鼠标事件
     */
    addTextItem(event: SMouseEvent) {
    }

    /**
     * 删除文本item
     * @param SMouseEvent  鼠标事件
     */
    deleiteItems(): void { }

    /**
     * 修改item样式
     * @param SMouseEvent  鼠标事件
     */
    updatedItems(): void { }

    /**
     * 对齐指定item
     * @param v
     */
    changeAlignItem(v: any): void {
        this.selectContainer.layout(v);
    }

    /**
     * 保存数据
     *
     * @return any 返回需要保存的数据
     */
    saveMsgItem(): any {
    }

    /**
     * 重做
     *
     * @return any
     */
    redo(): void {
    }

    /**
     * 撤销
     *
     * @return any
     */
    undo(): void {
    }

    /**
     * 完成创建的回调函数
     *
     * @param item 完成创建的item
     */
    finishCreated(item: SGraphItem) {
    }

    /**
    * 复制
    *
    */
    copy() { }

    /**
     * 粘贴
     *
     */
    paste() { }

    /**
     *  选中状态方法
     *
     *  @param  item SGraphItem
     */
    toggleItem(item: SGraphItem): void {
        this.selectContainer.clear()
        this.selectContainer.toggleItem(item)
    }

    /**
     * 框选
     */
    addRectSelect(event: SMouseEvent) {
        let point = new SPoint(event.x, event.y);
        let rect = new SRectSelectItem(null, point);
        this.addItem(rect);
        this.grabItem = rect;
    }

}// Class GraphEditScene